/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.newsletter.ribbon');

/**
 * Create the control instance.
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @class This class implements the behavior for an action.
 * @extends org.ametys.ribbon.control.RibbonControl
 */
org.ametys.newsletter.ribbon.CategoryActionButton = function(id, configuration, pluginName)
{
	org.ametys.newsletter.ribbon.CategoryActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.newsletter.ribbon.CategoryActionButton, org.ametys.ribbon.control.button.ActionButton, {});

org.ametys.newsletter.ribbon.CategoryActionButton.prototype.createControl = function(colspan)
{
	var elmt = org.ametys.newsletter.ribbon.CategoryActionButton.superclass.createControl.call(this, colspan);
	elmt.disable();
	return elmt;
}

/**
 * Creates the toggle button
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.newsletter.ribbon.CategoryActionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._checkTarget.createDelegate(this));
			
			if (target != null)
			{
				if (this._checkMode (target))
				{
					this._element.enable();
					this.updateTooltip(this.getConfiguration()["default-description"], null, null);
				}
				else
				{
					this._element.disable();
					this.updateTooltip(this.getConfiguration()["noeditable-description"], null, null);
				}
			}
			else
			{
				this._element.disable();
				this.updateTooltip(this.getConfiguration()["disabled-description"], null, null);
			}
			
		}
	}
}

org.ametys.newsletter.ribbon.CategoryActionButton.prototype._checkTarget = function (target)
{
	var types = this.getConfiguration()['type'].split('|');
	for (var i=0; i < types.length; i++)
	{
		if (target.getType() == types[i])
		{
			return true;
		}
	}
	return false;
}

org.ametys.newsletter.ribbon.CategoryActionButton.prototype._checkMode = function (target)
{
	var modes = this.getConfiguration()['mode'].split('|');
	for (var j=0; j < modes.length; j++)
	{
		if (target.getParameters().mode == modes[j])
		{
			return true;
		}
	}
	
	return false;
}

